TabPanelWidget | django_cradmin API Document

    import TabPanelWidget from 'django_cradmin/scripts/django_cradmin/widgets/TabPanelWidget.js'

public class | source

# TabPanelWidget

#### Extends:

ievv_jsbase/widget/AbstractWidget~AbstractWidget → TabPanelWidget

## Constructor Summary

Public Constructor
public | constructor(element: *) |

## Method Summary

Public Methods
public | destroy() |
public | getDefaultConfig(): * |
public | initializeFromTabButton(isActive: *, tabButtonDomId: *) |

## Public Constructors

### public constructor(element: *) source

#### Params:

Name | Type | Attribute | Description
element | * |  |

## Public Methods

### public destroy() source

### public getDefaultConfig(): * source

#### Return:

*

### public initializeFromTabButton(isActive: *, tabButtonDomId: *) source

#### Params:

Name | Type | Attribute | Description
isActive | * |  |
tabButtonDomId | * |  |